from enum import Enum, auto


class OperationMode(Enum):
    NONE = auto()
    ACTION = auto()
    TRAINING = auto()
